@@ -11,7 +11,7 @@ BackgroundDlg::BackgroundDlg(QWidget *parent) :
     blueString = "0";
 
     defaultImageSelected = true;
-    bgMode = "default";
+    bgMode = defaultBackground;
 
     pm = QPixmap(120,80);
     backgroundColor = (QColor(Qt::black));
@@ -21,10 +21,10 @@ BackgroundDlg::BackgroundDlg(QWidget *parent) :
     m_ui->colorButton->setIconSize(QSize(25,25));
     m_ui->colorButton->setIcon(colorDlgButtonIcon);
     m_ui->background->setAutoFillBackground(false);
-    m_ui->background->setPixmap(QPixmap(QString::fromUtf8(DEVICEDEFAULTLOGO)));
+    m_ui->background->setPixmap(QPixmap(qtirrecoImage));
     m_ui->background->setScaledContents(true);
     m_ui->background->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
-    backgroundPixmap = QPixmap(QString::fromUtf8(DEVICEDEFAULTLOGO)).scaled(800,424,Qt::IgnoreAspectRatio,Qt::FastTransformation);
+    backgroundPixmap = QPixmap(qtirrecoImage).scaled(800,424,Qt::IgnoreAspectRatio,Qt::FastTransformation);
     loadThemes();
 
     connect(m_ui->tabWidget,SIGNAL(currentChanged(int)),this,SLOT(activateTab(int)));
@@ -83,13 +83,13 @@ void BackgroundDlg::rgbFromColorDlg(const QString red,const QString green,const
 
 void BackgroundDlg::on_defaultImageButton_clicked()
 {
-    bgMode = "default";
+    bgMode = defaultBackground;
     defaultImageSelected = true;
     m_ui->background->clear();
     m_ui->background->setAutoFillBackground(false);
     m_ui->defaultImageButton->setChecked(true);
-    m_ui->background->setPixmap(QPixmap(QString::fromUtf8(DEVICEDEFAULTLOGO)));
-    backgroundPixmap = QPixmap(QString::fromUtf8(DEVICEDEFAULTLOGO));
+    m_ui->background->setPixmap(QPixmap(qtirrecoImage));
+    backgroundPixmap = QPixmap(qtirrecoImage);
 }
 
 void BackgroundDlg::on_colorButton_clicked()
@@ -104,12 +104,7 @@ void BackgroundDlg::on_colorButton_clicked()
     QIcon colorDlgButtonIcon = QIcon(pm);
     m_ui->colorButton->setIcon(colorDlgButtonIcon);
 
-    palette.setBrush(QPalette::Window, pm);
-    m_ui->background->setPalette(palette);
-    m_ui->background->setAutoFillBackground(true);
-    backgroundPixmap = pm;
-
-    bgMode = "color_only";
+    bgMode = backgroundFromColor;
     defaultImageSelected = false;
     m_ui->background->clear();
     m_ui->colorButton->setChecked(true);
@@ -142,35 +137,40 @@ void BackgroundDlg::on_imageButton_clicked()
          }
     }
     backgroundImagePath = bgImagePath;
-    bgMode = "image";
+    bgMode = backgroundFromImage;
     defaultImageSelected = false;
 }
 
 void BackgroundDlg::activateTab(const int tabIndex)
 {
-    if (tabIndex == 1) {
-        bgMode = "default";
+    if(tabIndex == 0) {
+        m_ui->listWidget_2->clear();
+        m_ui->previewLabel->clear();
+        m_ui->okButton->setDisabled(true);
+    }
+    else if (tabIndex == 1) {
+        bgMode = defaultBackground;
         defaultImageSelected = true;
         m_ui->background->clear();
         m_ui->background->setAutoFillBackground(false);
         m_ui->defaultImageButton->setChecked(true);
-        m_ui->background->setPixmap(QPixmap(QString::fromUtf8(DEVICEDEFAULTLOGO)));
-        backgroundPixmap = QPixmap(QString::fromUtf8(DEVICEDEFAULTLOGO));
+        m_ui->background->setPixmap(QPixmap(qtirrecoImage));
+        backgroundPixmap = QPixmap(qtirrecoImage);
     }
 }
 
 void BackgroundDlg::loadThemes()
 {
-    QDir *themeDirs = new QDir(DEVICETHEMES);
+    QDir *themeDirs = new QDir(themesPath);
 
     themeDirList = themeDirs->entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
 
     for(int i = 0 ; i < themeDirList.count() ; i++) {
         QListWidgetItem *item = new QListWidgetItem();
 
-        QString themeConf = DEVICETHEMES + themeDirList.at(i) + "/theme.conf";
+        QString themeConf = themesPath + themeDirList.at(i) + "/theme.conf";
         // Check if theme has any background directories.
-        QDir *themeBgDirs = new QDir(DEVICETHEMES + themeDirList.at(i) + "/bg/");
+        QDir *themeBgDirs = new QDir(themesPath + themeDirList.at(i) + "/bg/");
         QStringList themeBgs = themeBgDirs->entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
         if(!themeBgs.isEmpty()) {
             QFile file(themeConf);
@@ -194,10 +194,10 @@ void BackgroundDlg::loadThemes()
                 m_ui->listWidget->show();
             }
         }
-        else {
+       /* else {
                 themeDirList.removeAt(i);
                 i--;
-             }
+             }*/
     }
 }
 void BackgroundDlg::setBackgroundsOnListWidget2()
@@ -206,13 +206,13 @@ void BackgroundDlg::setBackgroundsOnListWidget2()
     m_ui->listWidget_2->clear();
 
     currentIndex = m_ui->listWidget->currentRow();
-    QDir *backgroundDirs = new QDir(DEVICETHEMES + themeDirList.at(currentIndex) +"/bg/");
+    QDir *backgroundDirs = new QDir(themesPath + themeDirList.at(currentIndex) +"/bg/");
     backgroundList = backgroundDirs->entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
 
     for(int i = 0 ; i < backgroundList.count() ; i++) {
         QListWidgetItem *item = new QListWidgetItem();
 
-        QString bgConf = DEVICETHEMES + themeDirList.at(currentIndex) + "/bg/" + backgroundList.at(i) +"/bg.conf";
+        QString bgConf = themesPath + themeDirList.at(currentIndex) + "/bg/" + backgroundList.at(i) +"/bg.conf";
         QFile file(bgConf);
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
             QMessageBox::warning(this,"Error with background config","Failed to load background name from config",
@@ -234,16 +234,17 @@ void BackgroundDlg::setBackgroundsOnListWidget2()
 
 void BackgroundDlg::setBackgroundOnPreviewLabel()
 {
-    bgMode = "theme";
+    bgMode = backgroundFromTheme;
     defaultImageSelected = false;
 
     QPixmap bgPreview(128,128);
-    QString string(DEVICETHEMES + themeDirList.at(currentIndex) +"/bg/"  + backgroundList.at(m_ui->listWidget_2->currentRow()) +"/image.png");
+    QString string(themesPath + themeDirList.at(currentIndex) +"/bg/"  + backgroundList.at(m_ui->listWidget_2->currentRow()) +"/image.png");
     bgPreview.load(string);
     backgroundImagePath = string;
     bgPreview = bgPreview.scaled(321,151,Qt::KeepAspectRatio,Qt::FastTransformation);
     m_ui->backgroundPreview->setPixmap(bgPreview);
     backgroundPixmap = bgPreview.scaled(800,424,Qt::IgnoreAspectRatio,Qt::FastTransformation);
+    m_ui->okButton->setEnabled(true);
 }
 
 void BackgroundDlg::process_line(QString line, const int CONF_TYPE)
