@@ -244,156 +244,156 @@ void ButtonWidget::checkButtonCommand()
 {
         if(fileNameUnPressed.contains("up",Qt::CaseSensitive) && buttonText == "Up" || buttonText == "up")
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/up/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/up/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/up/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "up/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "up/pressed.png";
+            confFileName = defaultButtonsPath + "up/button.conf";
             return;
         }
         if(fileNameUnPressed.contains("down",Qt::CaseSensitive) && buttonText == "Down" || buttonText == "down")
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/down/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/down/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/down/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "down/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "down/pressed.png";
+            confFileName = defaultButtonsPath + "down/button.conf";
             return;
         }
         if(fileNameUnPressed.contains("left",Qt::CaseSensitive) && buttonText == "Left" || buttonText == "left")
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/left/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/left/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/left/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "left/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "left/pressed.png";
+            confFileName = defaultButtonsPath + "left/button.conf";
             return;
         }
         if(fileNameUnPressed.contains("right",Qt::CaseSensitive) && buttonText == "Right" || buttonText == "right")
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/right/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/right/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/right/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "right/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "right/pressed.png";
+            confFileName = defaultButtonsPath + "right/button.conf";
             return;
         }
         if(fileNameUnPressed.contains("next",Qt::CaseInsensitive))
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/next/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/next/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/next/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "next/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "next/pressed.png";
+            confFileName = defaultButtonsPath + "next/button.conf";
             return;
         }
         if(fileNameUnPressed == "0" || fileNameUnPressed.contains("num_0",Qt::CaseInsensitive))
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/num_0/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/num_0/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/num_0/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "num_0/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "num_0/pressed.png";
+            confFileName = defaultButtonsPath + "num_0/button.conf";
             return;
         }
         if(fileNameUnPressed == "1" || fileNameUnPressed.contains("num_1",Qt::CaseInsensitive))
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/num_1/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/num_1/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/num_1/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "num_1/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "num_1/pressed.png";
+            confFileName = defaultButtonsPath + "num_1/button.conf";
             return;
         }
         if(fileNameUnPressed == "2" || fileNameUnPressed.contains("num_2",Qt::CaseInsensitive))
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/num_2/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/num_2/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/num_2/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "num_2/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "num_2/pressed.png";
+            confFileName = defaultButtonsPath + "num_2/button.conf";
             return;
         }
         if(fileNameUnPressed == "3" || fileNameUnPressed.contains("num_3",Qt::CaseInsensitive))
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/num_3/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/num_3/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/num_3/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "num_3/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "num_3/pressed.png";
+            confFileName = defaultButtonsPath + "num_3/button.conf";
             return;
         }
         if(fileNameUnPressed == "4" || fileNameUnPressed.contains("num_4",Qt::CaseInsensitive))
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/num_4/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/num_4/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/num_4/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "num_4/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "num_4/pressed.png";
+            confFileName = defaultButtonsPath + "num_4/button.conf";
             return;
         }
         if(fileNameUnPressed == "5" || fileNameUnPressed.contains("num_5",Qt::CaseInsensitive))
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/num_5/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/num_5/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/num_5/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "num_5/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "num_5/pressed.png";
+            confFileName = defaultButtonsPath + "num_5/button.conf";
             return;
         }
         if(fileNameUnPressed == "6" || fileNameUnPressed.contains("num_6",Qt::CaseInsensitive))
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/num_6/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/num_6/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/num_6/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "num_6/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "num_6/pressed.png";
+            confFileName = defaultButtonsPath + "num_6/button.conf";
             return;
         }
         if(fileNameUnPressed == "7" || fileNameUnPressed.contains("num_7",Qt::CaseInsensitive))
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/num_7/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/num_7/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/num_7/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "num_7/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "num_7/pressed.png";
+            confFileName = defaultButtonsPath + "num_7/button.conf";
             return;
         }
         if(fileNameUnPressed == "8" || fileNameUnPressed.contains("num_8",Qt::CaseInsensitive))
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/num_8/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/num_8/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/num_8/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "num_8/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "num_8/pressed.png";
+            confFileName = defaultButtonsPath + "num_8/button.conf";
             return;
         }
         if(fileNameUnPressed == "9" || fileNameUnPressed.contains("num_9",Qt::CaseInsensitive))
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/num_9/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/num_9/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/num_9/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "num_9/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "num_9/pressed.png";
+            confFileName = defaultButtonsPath + "num_9/button.conf";
             return;
         }
         if(fileNameUnPressed.contains("ok",Qt::CaseInsensitive))
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/ok/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/ok/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/ok/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "ok/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "ok/pressed.png";
+            confFileName = defaultButtonsPath + "ok/button.conf";
             return;
         }
         if(fileNameUnPressed.contains("pause",Qt::CaseInsensitive))
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/pause/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/pause/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/pause/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "pause/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "pause/pressed.png";
+            confFileName = defaultButtonsPath + "pause/button.conf";
             return;
         }
         if(fileNameUnPressed == "play" || fileNameUnPressed == "Play" || fileNameUnPressed == "PLAY")
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/right/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/right/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/right/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "right/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "right/pressed.png";
+            confFileName = defaultButtonsPath + "right/button.conf";
             return;
         }
         if(fileNameUnPressed.contains("play",Qt::CaseInsensitive) && fileNameUnPressed.contains("pause",Qt::CaseInsensitive))
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/pause/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/pause/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/pause/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "pause/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "pause/pressed.png";
+            confFileName = defaultButtonsPath + "pause/button.conf";
             return;
         }
         if(fileNameUnPressed.contains("power",Qt::CaseInsensitive) || fileNameUnPressed == "ONOFF" || fileNameUnPressed == "ON/OFF" ||
            fileNameUnPressed == "on/off" || fileNameUnPressed == "On/Off")
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/power/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/power/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/power/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "power/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "power/pressed.png";
+            confFileName = defaultButtonsPath + "power/button.conf";
             return;
         }
         if(fileNameUnPressed.contains("prev",Qt::CaseInsensitive))
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/prev/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/prev/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/prev/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "prev/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "prev/pressed.png";
+            confFileName = defaultButtonsPath + "prev/button.conf";
             return;
         }
         else
         {
-            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/blank/unpressed.png";
-            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/blank/pressed.png";
-            confFileName = "/home/user/.qtirreco/themes/default/buttons/blank/button.conf";
+            fileNameUnPressed = defaultButtonsPath + "blank/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "blank/pressed.png";
+            confFileName = defaultButtonsPath + "blank/button.conf";
         }
 }
