@@ -10,8 +10,9 @@ LayoutWidget::LayoutWidget(QMainWindow *parent ) : QWidget( parent )
     setAcceptDrops(true);
     useModeEnabled = true;
     buttonsVisible = true;
+    snapToGridEnabled = false;
     vector = new QVector<ButtonWidget*>;
-    bgPath = QString::fromUtf8("/home/user/.qtirreco/themes/default/bg/qtirreco/irreco_logo.png");
+    bgPath = qtirrecoImage;
     socket = new Socket(this);
     timer = new QTimer(this);
     timer2 = new QTimer(this);
@@ -19,7 +20,7 @@ LayoutWidget::LayoutWidget(QMainWindow *parent ) : QWidget( parent )
     timeout2 = 1;
     connect(timer,SIGNAL(timeout()),this,SLOT(sendIrCommandsSlot()));
     connect(timer2,SIGNAL(timeout()),this,SLOT(sendIrCommandsSlot2()));
-    timeout = 1000;
+    timeout = 500;
     timer->setInterval(timeout);
     timer2->setInterval(timeout2);
     socket->create();
@@ -29,7 +30,6 @@ LayoutWidget::LayoutWidget(QMainWindow *parent ) : QWidget( parent )
 
 LayoutWidget::~LayoutWidget()
 {
-    //socket->closeSocket();
 
 }
 void LayoutWidget::setUseModeEnabled(bool useMode)
@@ -52,8 +52,8 @@ void LayoutWidget::openEditDlg()
     connect(newButtonDlg,SIGNAL(addButtonToLayoutSignal(QString,QString, QString, QString,QStringList,int,int)),
             this,SLOT(editButton(QString,QString, QString, QString, QStringList,int,int)));
 
-    newButtonDlg->exec();
-    delete newButtonDlg;
+    newButtonDlg->setModal(true);
+    newButtonDlg->show();
 }
 
 void LayoutWidget::editButton(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, int number, int timeOut)
@@ -72,9 +72,14 @@ void LayoutWidget::editButton(QString fileNameUnPressed, QString fileNamePressed
      pw->move(position);
      pw->show();
      newButton->deleteLater();
-     emit showOrHideMenu();
 }
+void LayoutWidget::snapToGrid()
+{
+     if(snapToGridEnabled)
+        snapToGridEnabled = false;
 
+    else snapToGridEnabled = true;
+}
 void LayoutWidget::mousePressEvent(QMouseEvent *event)
 {
     ButtonWidget *child = static_cast<ButtonWidget*>(childAt(event->pos()));
@@ -95,26 +100,34 @@ void LayoutWidget::mousePressEvent(QMouseEvent *event)
     mimeData->setData("application/x-qtirreco", itemData);
     mimeData->setText(child->fileNameUnPressed);
 
-    if(useModeEnabled) {
-        copyButton = child;
-        QDrag *drag = new QDrag(this);
-        drag->setMimeData(mimeData);
-        drag->setPixmap(*child->pressedPixmap);
-        drag->setHotSpot(hotSpot);
-        drag->exec();
-            if(child->commandChain.count() < 2)
-                this->sendIrCommands(child->commandChain);
+    copyButton = child;
+    QDrag *drag = new QDrag(this);
+    drag->setMimeData(mimeData);
 
+    QPainter p;
+    p.begin(copyButton->pressedPixmap);
+    p.save();
+    p.drawPixmap(0, 0, *copyButton->pressedPixmap );
+    if(copyButton->allowText && !copyButton->buttonText.contains("blank",Qt::CaseInsensitive)) {
+        p.setPen(*copyButton->textUpColor);
+        p.setFont(*copyButton->textUpFont);
+        p.drawText(copyButton->rect(),Qt::AlignCenter,copyButton->buttonText);
+    }
+    p.restore();
+    p.end();
+
+    drag->setPixmap(*copyButton->pressedPixmap);
+    drag->setHotSpot(hotSpot);
+
+    if(useModeEnabled) {
+
+        if(copyButton->commandChain.count() == 1)
+                this->sendIrCommands(copyButton->commandChain);
+         drag->exec(Qt::IgnoreAction, Qt::IgnoreAction);
     }
     else {
-        QDrag *drag = new QDrag(this);
-        drag->setMimeData(mimeData);
-        drag->setPixmap(*child->pressedPixmap);
-
-        drag->setHotSpot(hotSpot);
 
         child->hide();
-
         if (drag->exec(Qt::MoveAction | Qt::CopyAction, Qt::CopyAction) == Qt::MoveAction)
             child->close();
         else child->show();
@@ -123,71 +136,42 @@ void LayoutWidget::mousePressEvent(QMouseEvent *event)
 
 void LayoutWidget::dragEnterEvent(QDragEnterEvent *event)
  {
-    if(!useModeEnabled) {
-         if (event->mimeData()->hasFormat("application/x-qtirreco")) {
-         if (children().contains(event->source())) {
-             event->setDropAction(Qt::MoveAction);
-             event->accept();
-             } else
-                 event->acceptProposedAction();
-
-         } else if (event->mimeData()->hasText())
-             event->acceptProposedAction();
-          else
-             event->ignore();
-
-    }
-    else {
+    if(useModeEnabled){
         if(copyButton->commandChain.count() > 1 && copyButton->underMouse())
             this->sendIrCommands(copyButton->commandChain);
-        else if(copyButton->underMouse() && !timer->isActive()) {
-            timeout = 1000;
+        else if(copyButton->underMouse() && !timer->isActive() && copyButton->commandChain.count() == 1) {
+            timeout = 500;
             timer->setInterval(timeout);
             timer->start();
+         }
+    }
+
+    if (event->mimeData()->hasFormat("application/x-qtirreco")) {
+    if (children().contains(event->source())) {
+        event->setDropAction(Qt::MoveAction);
+        event->accept();
         }
-          if (event->mimeData()->hasFormat("application/x-qtirreco")) {
-         if (children().contains(event->source())) {
-             event->setDropAction(Qt::MoveAction);
-             event->accept();
-             } else
-                 event->acceptProposedAction();
+    else    event->acceptProposedAction();
+    }
+    else if (event->mimeData()->hasText())
+        event->acceptProposedAction();
+    else
+        event->ignore();
 
-         } else if (event->mimeData()->hasText())
-             event->acceptProposedAction();
-          else
-             event->ignore();
-     }
  }
  void LayoutWidget::dragMoveEvent(QDragMoveEvent *event)
  {
-     if(!useModeEnabled) {
-        if (event->mimeData()->hasFormat("application/x-qtirreco")) {
-             if (children().contains(event->source())) {
-                 event->setDropAction(Qt::MoveAction);
-                 event->accept();
-             } else
-                 event->acceptProposedAction();
-
-         } else if (event->mimeData()->hasText())
-             event->acceptProposedAction();
-          else
-             event->ignore();
-
-     }
-     else {
-         if (event->mimeData()->hasFormat("application/x-qtirreco")) {
+    if (event->mimeData()->hasFormat("application/x-qtirreco")) {
          if (children().contains(event->source())) {
              event->setDropAction(Qt::MoveAction);
              event->accept();
-             } else
-                 event->acceptProposedAction();
-
-         } else if (event->mimeData()->hasText())
+         } else
              event->acceptProposedAction();
-          else
-             event->ignore();
-     }
 
+     } else if (event->mimeData()->hasText())
+         event->acceptProposedAction();
+      else
+         event->ignore();
  }
  void LayoutWidget::dropEvent(QDropEvent *event)
  {
@@ -210,6 +194,21 @@ void LayoutWidget::dragEnterEvent(QDragEnterEvent *event)
              newButton = new ButtonWidget(this, fileNameUnPressed, fileNamePressed, confFileName, buttonText, commands, timeOut);
              newButton->move(event->pos() - offset);
              newButton->show();
+             // If snap to grid enabled move button.
+             if(snapToGridEnabled) {
+                QPoint oldPos = newButton->pos();
+                int xMultiplier = oldPos.x() / 16;
+                int dividedX = oldPos.x() % 16;
+                if(dividedX > 8)
+                    xMultiplier +=1;
+
+                int yMultiplier = oldPos.y() / 16;
+                int dividedY = oldPos.y() % 16;
+                if(dividedY > 8)
+                    yMultiplier +=1;
+
+                newButton->move(xMultiplier*16, yMultiplier*16);
+             }
              newButton->setAttribute(Qt::WA_DeleteOnClose);
 
              int buttonWidgets;
@@ -232,48 +231,43 @@ void LayoutWidget::dragEnterEvent(QDragEnterEvent *event)
          // Move button to limit area if it goes over screen area
          int buttonWidth = newButton->width();
          int buttonHeight = newButton->height();
-         bool negativePos = false;
 
          if(((newButton->x())+(buttonWidth)) > 800)
             newButton->move(800-buttonWidth,newButton->y());
 
          if(newButton->x() < 0) {
             newButton->move(0,newButton->y());
-            negativePos = true;
          }
          if(newButton->y()+buttonHeight > 424)
             newButton->move(newButton->x(),424 - buttonHeight);
 
          if(newButton->y() <= 0) {
             newButton->move(newButton->x(),0);
-            negativePos = true;
          }
          // End
-          if(!negativePos) {
-             if((xPos-newButton->x()) < 30 && (xPos-newButton->x()) > -30 &&
-                    (yPos-newButton->y()) < 30 && (yPos-newButton->y()) > -30) {
+         if((xPos-newButton->x()) < 16 && (xPos-newButton->x()) > -16 &&
+                (yPos-newButton->y()) < 16 && (yPos-newButton->y()) > -16) {
 
-                 QMenu *menu = new QMenu(newButton);
+             QMenu *menu = new QMenu(newButton);
 
-                 if(newButton->x() <= 300)
-                     menu->setGeometry(QRect(newButton->x()+105,newButton->y()+75,50,20));
+             if(newButton->x() <= 300)
+                 menu->setGeometry(QRect(newButton->x()+105,newButton->y()+75,50,20));
 
-                 else menu->setGeometry(QRect(newButton->x()-235,newButton->y()+75,50,20));
+             else menu->setGeometry(QRect(newButton->x()-235,newButton->y()+75,50,20));
 
-                 menu->setFont(QFont("sans-serif",22,QFont::Bold));
-                 QAction *editButton = menu->addAction("Edit button");
-                 menu->addSeparator();
-                 QAction *deleteButton = menu->addAction("Delete button");
+             menu->setFont(QFont("sans-serif",22,QFont::Bold));
+             QAction *editButton = menu->addAction("Edit button");
+             menu->addSeparator();
+             QAction *deleteButton = menu->addAction("Delete button");
 
-                 connect(editButton,SIGNAL(triggered()),this,SLOT(openEditDlg()));
-                 connect(deleteButton,SIGNAL(triggered()),this,SLOT(deleteButton()));
-                 menu->show();
-             }
+             connect(editButton,SIGNAL(triggered()),this,SLOT(openEditDlg()));
+             connect(deleteButton,SIGNAL(triggered()),this,SLOT(deleteButton()));
+             menu->show();
          }
      }
     else {
         timer->stop();
-        //timeout = 1000;
+        timeout = 500;
         }
 }
 void LayoutWidget::deleteButton()
@@ -299,7 +293,7 @@ void LayoutWidget::addButton(QString fileNameUnPressed, QString fileNamePressed,
 
 void LayoutWidget::addButton(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, int aNumber)
 {
-     int timeOut = 600;
+     int timeOut = 500;
      ButtonWidget *pw = new ButtonWidget(this, fileNameUnPressed, fileNamePressed, confFileName, buttonText, commands, timeOut);
      number = aNumber;
      int xPlace = 0;
@@ -321,7 +315,7 @@ void LayoutWidget::addButton(QString fileNameUnPressed, QString fileNamePressed,
     pw->show();
  }
 
- void LayoutWidget::setBackgroundMode(QString mode)
+ void LayoutWidget::setBackgroundMode(int mode)
  {
     backgroundMode = mode;
  }
@@ -342,7 +336,7 @@ void LayoutWidget::addButton(QString fileNameUnPressed, QString fileNamePressed,
  {
      QStringList themesUsed;
      QStringList themeVersionsUsed;
-     if(backgroundMode == "theme") {
+     if(backgroundMode == backgroundFromTheme) {
         QString bgTheme = bgPath;
         bgTheme = bgTheme.remove(0,34);
         int slashIndex = bgTheme.indexOf(QChar('/'));
@@ -365,7 +359,7 @@ void LayoutWidget::addButton(QString fileNameUnPressed, QString fileNamePressed,
     }
 
     for( int i=0 ; i< themesUsed.count() ; i++ ) {
-        QFile themeConf("/home/user/MyDocs/qtirreco/themes/" + themesUsed.at(i) + "/theme.conf");
+        QFile themeConf(themesPath + themesUsed.at(i) + "/theme.conf");
         themeConf.open(QIODevice::ReadOnly | QIODevice::Text);
         QTextStream in(&themeConf);
         QString version;
@@ -381,33 +375,39 @@ void LayoutWidget::addButton(QString fileNameUnPressed, QString fileNamePressed,
 
 
     QDir dir;
-    if(!dir.exists(DEVICEREMOTES))
-            dir.mkpath(DEVICEREMOTES);
+    if(!dir.exists(remotesPath))
+            dir.mkpath(remotesPath);
 
-    QFile exFile(DEVICEREMOTES + activeRemoteName+".conf");
+    QFile exFile(remotesPath + activeRemoteName+".conf");
     exFile.remove();
-    QFile file(DEVICEREMOTES + activeRemoteName +".conf");
+    QFile file(remotesPath + activeRemoteName +".conf");
     file.open(QIODevice::WriteOnly | QIODevice::Text);
 
     QTextStream out(&file);
 
-    if(backgroundMode == "default") {
-        out << "Background: default \n";
-        out << "Image: default \n";
+    switch(backgroundMode) {
+        case defaultBackground:
+            out << "Background: default \n";
+            out << "Image: default \n";
+            break;
+        case backgroundFromTheme:
+            out << "Background: theme \n";
+            out << "Image: "<< bgPath <<"\n";
+            break;
+        case backgroundFromImage:
+            out << "Background: image \n";
+            out << "Image: "<< bgPath <<"\n";
+            break;
+        case backgroundFromColor:
+            out << "Background: color_only \n";
+            out << "Color: " << r <<" "<< g <<" " << b << "\n";
+            break;
+        default:
+            out << "Background: default \n";
+            out << "Image: default \n";
+            break;
     }
-    else if(backgroundMode == "theme") {
 
-        out << "Background: theme \n";
-        out << "Image: "<< bgPath <<"\n";
-    }
-    else if(backgroundMode == "image") {
-        out << "Background: image \n";
-        out << "Image: "<< bgPath <<"\n";
-    }
-    else if(backgroundMode == "color_only") {
-        out << "Background: color_only \n";
-        out << "Color: " << r <<" "<< g <<" " << b << "\n";
-    }
     int buttonCount = vector->count();
     if(buttonCount > 0) {
         for(int i=0 ; i < buttonCount ; i++) {
