@@ -29,7 +29,7 @@ public:
     //! Current background path.
     QString bgPath;
     //! Current background mode.
-    QString backgroundMode;
+    int backgroundMode;
     //! Selected button index in vector.
     int currentButtonIndex;
     //! Methods to add button to layout.
@@ -43,6 +43,8 @@ public:
     Socket *socket;
     //! Vector for all buttons on layout.
     QVector<ButtonWidget*> *vector;
+    //! Boolean to tell if snap to grid enabled.
+    bool snapToGridEnabled;
 
 
 private:
@@ -73,13 +75,13 @@ private:
     //! Index of commandchain used by timer2.
     int timer2Index;
 
+
 protected:
     void mousePressEvent(QMouseEvent *event);
     void dragEnterEvent(QDragEnterEvent *event);
     void dragMoveEvent(QDragMoveEvent *event);
     void dropEvent(QDropEvent *event);
 
-
 signals:
     //! Emitted for QtIrreco to hide or show menu buttons.
     void showOrHideMenu();
@@ -93,7 +95,7 @@ public slots:
     //! Opens new button dialog but used for editing existing button.
     void editButton(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, int number, int timeOut);
     //! Slot to change current background mode.
-    void setBackgroundMode(QString mode);
+    void setBackgroundMode(int mode);
     //! Slot to set RGB values and mode.
     void setRgbValues(QString red,QString green,QString blue);
     //! Slot to set active remote name.
@@ -104,6 +106,8 @@ public slots:
     void setBackgroundImagePath(QString bgImagePath);
     //! Slot to clear LayoutWidget from buttons.
     void clearScreen();
+    //! Arrange buttons properly
+    void snapToGrid();
 
 private slots:
     //! Slot called when button pressed and it has command.
