@@ -4,21 +4,9 @@
 QtIrreco::QtIrreco(QWidget *parent)
     : QMainWindow(parent), ui(new Ui::QtIrrecoClass)
 {
-  /*  QDir dir;
-    if(!dir.exists("/home/user/MyDocs/qtirreco"))
-         system("mkdir /home/user/MyDocs/qtirreco");
-
-    if(!dir.exists("/home/user/MyDocs/qtirreco/Remotes"))
-         system("mkdir /home/user/MyDocs/qtirreco/Remotes");
-
-    if(!dir.exists("/home/user/MyDocs/qtirreco/Devices"))
-        system("mkdir /home/user/MyDocs/qtirreco/Devices");
-
-    if(!dir.exists("/home/user/MyDocs/qtirreco/themes"))
-        system("/home/user/MyDocs/qtirreco/themes"); */
 
      //Creates empty remotes.conf file
-    QFile file(DEVICECONF);
+    QFile file(remotesConf);
     if (!file.open(QIODevice::ReadWrite | QIODevice::Text))
         return;
     file.close();
@@ -39,12 +27,10 @@ QtIrreco::QtIrreco(QWidget *parent)
 
     connect(lw,SIGNAL(showOrHideMenu()),this,SLOT(showOrHideButtons()));
     connect(this,SIGNAL(remoteNameToLw(QString)),lw,SLOT(setActiveRemoteName(QString)));
-    connect(lw,SIGNAL(saveFailed()),this,SLOT(showSaveError()));
     connect(this,SIGNAL(bgImageToLw(QString)),lw,SLOT(setBackgroundImagePath(QString)));
     connect(this,SIGNAL(rgbToLw(int,int,int)),lw,SLOT(setRgbInteger(int,int,int)));
     connect(this,SIGNAL(remoteDeleted()),lw,SLOT(clearScreen()));
 
-
     createButtons();
     connectButtons();
 
@@ -75,7 +61,7 @@ void QtIrreco::setActiveRemote()
 {
      lw->setActiveRemoteName(activeRemote);
      backgroundName.clear();
-     QFile file(DEVICEREMOTES + activeRemote+".conf");
+     QFile file(remotesPath + activeRemote+".conf");
         if (!file.open(QIODevice::ReadWrite | QIODevice::Text))
             return;
         QTextStream in(&file);
@@ -91,7 +77,7 @@ void QtIrreco::checkForRemotes()
     remoteIndex = 0;
     QDir dir;
 
-    QFile file(DEVICECONF);
+    QFile file(remotesConf);
 
     if (!file.open(QIODevice::ReadWrite | QIODevice::Text))
         return;
@@ -111,16 +97,16 @@ void QtIrreco::noRemotes()
     activeRemote.clear();
     this->setWindowTitle("Please make a new remote!");
     // Remove all files in Remotes
-    QDir dir(DEVICEREMOTES);
+    QDir dir(remotesPath);
     QStringList files = dir.entryList(QDir::Files);
     for(int i=0;i<files.count(); i++) {
-        QFile file(DEVICEREMOTES + files.at(i));
+        QFile file(remotesPath + files.at(i));
         file.remove();
     }
 
     // Creates empty remotes.conf file
 
-     QFile file(DEVICECONF);
+     QFile file(remotesConf);
 
      if (!file.open(QIODevice::ReadWrite | QIODevice::Text))
          return;
@@ -135,7 +121,7 @@ void QtIrreco::noRemotes()
      this->setPalette(palette);
      this->setAutoFillBackground(true);
 
-     palette.setBrush(QPalette::Window, QPixmap(QString::fromUtf8(DEVICEDEFAULTIMAGE)).scaled(800,424,Qt::IgnoreAspectRatio,Qt::FastTransformation));
+     palette.setBrush(QPalette::Window, QPixmap(qtirrecoImage).scaled(800,424,Qt::IgnoreAspectRatio,Qt::FastTransformation));
      lw->setPalette(palette);
      lw->setAutoFillBackground(true);
 }
@@ -170,6 +156,7 @@ void QtIrreco::hideEditModeButtons()
     newPushButton->hide();
     renameButton->hide();
     backgroundButton->hide();
+    snapButton->hide();
     buttonsVisible = false;
     lw->setButtonsVisible(buttonsVisible);
 }
@@ -180,6 +167,7 @@ void QtIrreco::showEditModeButtons()
     newPushButton->show();
     renameButton->show();
     backgroundButton->show();
+    snapButton->show();
     buttonsVisible = true;
 }
 
@@ -275,19 +263,21 @@ void QtIrreco::createRemote(QString newRemoteName)
     }
     if(!alreadyExists) {
         QDir dir;
-        QFile newRemoteFile(DEVICEREMOTES + newRemoteName+".conf");
+        QFile newRemoteFile(remotesPath + newRemoteName+".conf");
         if (!newRemoteFile.open(QIODevice::ReadWrite | QIODevice::Text))
             return;
         lw->clearScreen();
-        lw->setBackgroundMode("default");
-        lw->setBackgroundImagePath(DEVICEDEFAULTIMAGE);
+        backgroundMode = defaultBackground;
+        lw->setBackgroundMode(backgroundMode);
+
+        lw->setBackgroundImagePath(qtirrecoImage);
 
         QColor defaultBgColor(50,50,50);
         palette.setColor(QPalette::Window,defaultBgColor);
         this->setPalette(palette);
         this->setAutoFillBackground(true);
 
-        palette.setBrush(QPalette::Window, QPixmap(QString::fromUtf8(DEVICEDEFAULTIMAGE)).scaled(800,424,Qt::IgnoreAspectRatio,Qt::FastTransformation));
+        palette.setBrush(QPalette::Window, QPixmap(qtirrecoImage).scaled(800,424,Qt::IgnoreAspectRatio,Qt::FastTransformation));
 
         lw->setPalette(palette);
         lw->setAutoFillBackground(true);
@@ -346,7 +336,7 @@ void QtIrreco::changeNewRemoteName(QString newName)
     }
     else {
         oldRemoteName = activeRemote;
-        QFile remoteFile(DEVICEREMOTES + oldRemoteName + ".conf");
+        QFile remoteFile(remotesPath + oldRemoteName + ".conf");
         remoteFile.rename(newName+".conf");
         activeRemote = newName;
         this->setWindowTitle("QtIrreco:"+activeRemote+" - Click to hide menu");
@@ -369,9 +359,9 @@ void QtIrreco::changeNewRemoteName(QString newName)
 
 void QtIrreco::writeRemoteChanges() // when renaming remote or changing active remote or deleting remote
 {
-    QFile exConf(DEVICECONF);
+    QFile exConf(remotesConf);
     exConf.remove();
-    QFile newConf(DEVICECONF);
+    QFile newConf(remotesConf);
           if (!newConf.open(QIODevice::ReadWrite | QIODevice::Text))
           return;
           QTextStream in(&newConf);
@@ -402,24 +392,18 @@ void QtIrreco::addRemoteName(QString newRemoteName)
     showButton->setEnabled(true);
     deleteButton->setEnabled(true);
 
-   /* this->showEditModeButtons();
-    this->hideUseModeButtons();
-    useModeEnabled = false;
-    lw->setUseModeEnabled(useModeEnabled); */
-
-
-
     buttonsVisible = true;
     lw->setFocus();
-    lw->setBackgroundImagePath(DEVICEDEFAULTIMAGE);
-    lw->setBackgroundMode("default");
+    lw->setBackgroundImagePath(qtirrecoImage);
+    backgroundMode = defaultBackground;
+    lw->setBackgroundMode(backgroundMode);
 
     QColor defaultBgColor(50,50,50);
     palette.setColor(QPalette::Window,defaultBgColor);
     this->setPalette(palette);
     this->setAutoFillBackground(true);
 
-    palette.setBrush(QPalette::Window, QPixmap(QString::fromUtf8(DEVICEDEFAULTIMAGE)).scaled(800,424,Qt::IgnoreAspectRatio,Qt::FastTransformation));
+    palette.setBrush(QPalette::Window, QPixmap(qtirrecoImage).scaled(800,424,Qt::IgnoreAspectRatio,Qt::FastTransformation));
     lw->setPalette(palette);
     lw->setAutoFillBackground(true);
 
@@ -478,7 +462,7 @@ void QtIrreco::deleteActiveRemote()
 {
     emit remoteDeleted();
 
-    QFile file(DEVICEREMOTES +activeRemote+".conf");
+    QFile file(remotesPath +activeRemote+".conf");
     file.remove();
     for (int i=0;i<remoteNames->count();i++) {
         if(remoteNames->at(i).contains(activeRemote+".conf"))
@@ -499,7 +483,7 @@ void QtIrreco::deleteActiveRemote()
     this->checkForRemotes();
     if(remoteNames->count() <= 0) {
        activeRemote.clear();
-       QFile confFile(DEVICECONF);
+       QFile confFile(remotesConf);
        confFile.remove();
        this->noRemotes();
     }
@@ -539,7 +523,7 @@ void QtIrreco::saveRemote()
     lw->saveRemoteToFile();
     lircFileNames.clear();
 
-    QFile file(DEVICEREMOTES + activeRemote+".conf");
+    QFile file(remotesPath + activeRemote+".conf");
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
     return;
     QTextStream stream(&file);
@@ -568,7 +552,7 @@ void QtIrreco::saveRemote()
 
     file.close();
     QStringList lircFilePaths;
-    QFile lircPathsFile("/home/user/MyDocs/qtirreco/lircpaths.conf");
+    QFile lircPathsFile(lircpathsConf);
     lircPathsFile.open(QIODevice::ReadOnly | QIODevice::Text);
     QTextStream in(&lircPathsFile);
     while (!in.atEnd()) {
@@ -586,7 +570,7 @@ void QtIrreco::saveRemote()
     }
     lircPathsFile.close();
 
-    QFile remFile(DEVICEREMOTES + activeRemote +".conf");
+    QFile remFile(remotesPath + activeRemote +".conf");
     remFile.open(QIODevice::WriteOnly | QIODevice::Append);
 
 
@@ -712,7 +696,7 @@ void QtIrreco::showRemote()
             activeRemote.clear();
             remoteNames->clear();
 
-            QFile file(DEVICECONF);
+            QFile file(remotesConf);
             if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
             return;
             QTextStream in(&file);
@@ -729,10 +713,17 @@ void QtIrreco::showRemote()
 void QtIrreco::readRemoteFile(QString line)
 {
     if(line.contains("Background: ",Qt::CaseInsensitive)) {
-        backgroundMode.clear();
         line = line.trimmed();
         line.remove(0,12);
-        backgroundMode = line;
+        if(line.contains("default"),Qt::CaseInsensitive)
+            backgroundMode = defaultBackground;
+        if(line.contains("theme"),Qt::CaseInsensitive)
+            backgroundMode = backgroundFromTheme;
+        if(line.contains("image"),Qt::CaseInsensitive)
+            backgroundMode = backgroundFromImage;
+        if(line.contains("color"),Qt::CaseInsensitive)
+            backgroundMode = backgroundFromColor;
+
         lw->setBackgroundMode(backgroundMode);
     }
     if(line.contains("Image: ",Qt::CaseInsensitive)) {
@@ -964,8 +955,8 @@ void QtIrreco::scrollRemoteButtons(int index)
 void QtIrreco::background()
 {
     bg = new BackgroundDlg(this);
-    connect(bg,SIGNAL(backgroundChanged(QString)),lw,SLOT(setBackgroundMode(QString)));
-    connect(bg,SIGNAL(backgroundChanged(QString)),this,SLOT(changeBackground()));
+    connect(bg,SIGNAL(backgroundChanged(int)),lw,SLOT(setBackgroundMode(int)));
+    connect(bg,SIGNAL(backgroundChanged(int)),this,SLOT(changeBackground()));
     connect(bg,SIGNAL(rgbToLw(QString,QString,QString)),lw,SLOT(setRgbValues(QString,QString,QString)));
     bg->exec();
 }
@@ -980,7 +971,7 @@ void QtIrreco::changeBackground()
         this->setPalette(palette);
         this->setAutoFillBackground(true);
 
-        palette.setBrush(QPalette::Window, QPixmap(QString::fromUtf8(DEVICEDEFAULTIMAGE)).scaled(800,424,Qt::IgnoreAspectRatio,Qt::FastTransformation));
+        palette.setBrush(QPalette::Window, QPixmap(qtirrecoImage).scaled(800,424,Qt::IgnoreAspectRatio,Qt::FastTransformation));
         lw->setPalette(palette);
         lw->setAutoFillBackground(true);
     }
@@ -1008,7 +999,7 @@ void QtIrreco::changeBackground(QString backgroundName, QColor backgroundColor)
         this->setPalette(palette);
         this->setAutoFillBackground(true);
 
-        palette.setBrush(QPalette::Window, QPixmap(QString::fromUtf8(DEVICEDEFAULTIMAGE)).scaled(800,424,Qt::IgnoreAspectRatio,Qt::FastTransformation));
+        palette.setBrush(QPalette::Window, QPixmap(qtirrecoImage).scaled(800,424,Qt::IgnoreAspectRatio,Qt::FastTransformation));
         lw->setPalette(palette);
         lw->setAutoFillBackground(true);
     }
@@ -1075,7 +1066,11 @@ void QtIrreco::createButtons()
     newPushButton = new QPushButton(this);
     newPushButton->setObjectName(QString::fromUtf8("newButton"));
     newPushButton->setText("New Button");
-    newPushButton->setGeometry(QRect(120, 140, 400, 100));
+    newPushButton->setGeometry(QRect(120, 140, 200, 100));
+    snapButton = new QPushButton(this);
+    snapButton->setObjectName(QString::fromUtf8("snapButton"));
+    snapButton->setText("Snap to grid: Off");
+    snapButton->setGeometry(QRect(320, 140, 200, 100));
     renameButton = new QPushButton(this);
     renameButton->setObjectName(QString::fromUtf8("renameButton"));
     renameButton->setText("Rename Remote");
@@ -1102,13 +1097,16 @@ void QtIrreco::connectButtons()
     connect(newPushButton,SIGNAL(clicked()),this,SLOT(newButton()));
     connect(saveButton,SIGNAL(clicked()),this,SLOT(saveRemote()));
     connect(backgroundButton,SIGNAL(clicked()),this,SLOT(background()));
+    connect(snapButton,SIGNAL(clicked()),this,SLOT(snapToGrid()));
 }
-
-void QtIrreco::showSaveError()
+void QtIrreco::snapToGrid()
 {
-    QMessageBox::warning(this,"Error occured with saving","Please try saving remote again.Current mode: "+backgroundMode+
-                         "\nCurrent background: "+backgroundName+"!",
-                     QMessageBox::NoButton,QMessageBox::NoButton);
+    if(lw->snapToGridEnabled)
+        snapButton->setText("Snap to grid: Off");
+
+    else snapButton->setText("Snap to grid: On");
+
+    lw->snapToGrid();
 }
 
 void QtIrreco::addDownloadedRemote(QString remName)
@@ -1138,7 +1136,7 @@ void QtIrreco::addDownloadedRemote(QString remName)
 void QtIrreco::checkThemesForRemote(QString remoteFile)
 {
     QString themeTemp;
-    QFile file(DEVICEREMOTES + remoteFile);
+    QFile file(remotesPath + remoteFile);
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
         return;
         QTextStream in(&file);
@@ -1254,7 +1252,7 @@ void QtIrreco::checkLircFilesForRemote(QString remoteFile)
     QString temp;
     lircPathsForRemote.clear();
     lircConfs.clear();
-    QFile file(DEVICEREMOTES + remoteFile);
+    QFile file(remotesPath + remoteFile);
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
     return;
     QTextStream in(&file);
@@ -1287,7 +1285,7 @@ void QtIrreco::checkLircFilesForRemote(QString remoteFile)
         }
     }
     file.close();
-    QDir dir(DEVICES);
+    QDir dir(devicesPath);
     for(int i=lircConfs.length()-1;i>-1;i--) {
         if(dir.exists(lircConfs.at(i))) {
             lircConfs.removeAt(i);
@@ -1473,8 +1471,8 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         this->getThemeBackgroundsByIds();
     }
     if (Id == fileId) {
-        if(!QFile::exists(DEVICES + lircConfs.at(callCounter-1))) {
-            QFile deviceFile(DEVICES +lircConfs.at(callCounter-1));
+        if(!QFile::exists(devicesPath + lircConfs.at(callCounter-1))) {
+            QFile deviceFile(devicesPath +lircConfs.at(callCounter-1));
             deviceFile.open(QIODevice::WriteOnly | QIODevice::Text);
             QTextStream out(&deviceFile);
             for(int i= 0; i< sList.count();i++)
@@ -1508,7 +1506,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
             }
             LircConfFile.close();
 
-            QFile lircPathsFile("/home/user/MyDocs/qtirreco/lircpaths.conf");
+            QFile lircPathsFile(lircpathsConf);
             lircPathsFile.open(QIODevice::WriteOnly | QIODevice::Append);
             QTextStream stream(&lircPathsFile);
             stream << lircConfs.at(callCounter-1) + " "+ lircPathsForRemote.at(callCounter-1) + "\n";
