@@ -97,7 +97,7 @@ void ThemeManager::updateListWidget(QListWidgetItem *item)
         {
             if(item->text().contains(themeDirList.at(i),Qt::CaseInsensitive))
             {
-                QFile file("/home/user/MyDocs/qtirreco/themes/"+themeDirList.at(i)+"/theme.conf");
+                QFile file(themesPath+themeDirList.at(i)+"/theme.conf");
                 tName = themeDirList.at(i);
                 if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
                 {
@@ -299,11 +299,11 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
         QVariant folder = array.value("folder");
 
         QDir dir;
-        dir.mkpath("/home/user/MyDocs/qtirreco/themes/"+m_ui->nameLabel->text().toLower()+"/buttons/"+folder.toString().toLower());
-        buttonPath = QString("/home/user/MyDocs/qtirreco/themes/"+m_ui->nameLabel->text().toLower()+"/buttons/"+folder.toString().toLower());
+        dir.mkpath(themesPath+m_ui->nameLabel->text().toLower()+"/buttons/"+folder.toString().toLower());
+        buttonPath = QString(themesPath+m_ui->nameLabel->text().toLower()+"/buttons/"+folder.toString().toLower());
         if(themeButtonIndex == 1)
         {
-            QFile themeConf("/home/user/MyDocs/qtirreco/themes/"+m_ui->nameLabel->text().toLower()+"/theme.conf");
+            QFile themeConf(themesPath+m_ui->nameLabel->text().toLower()+"/theme.conf");
             if (!themeConf.open(QIODevice::ReadWrite | QIODevice::Text))
             return;
             QTextStream in(&themeConf);
@@ -395,8 +395,8 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
         QVariant folder = array.value("folder");
 
         QDir dir;
-        dir.mkpath("/home/user/MyDocs/qtirreco/themes/"+m_ui->nameLabel->text().toLower()+"/bg/"+folder.toString());
-        bgPath = QString("/home/user/MyDocs/qtirreco/themes/"+m_ui->nameLabel->text().toLower()+"/bg/"+folder.toString());
+        dir.mkpath(themesPath + m_ui->nameLabel->text().toLower()+"/bg/"+folder.toString());
+        bgPath = QString(themesPath + m_ui->nameLabel->text().toLower()+"/bg/"+folder.toString());
 
         QFile bgConf(bgPath+"/bg.conf");
         if (!bgConf.open(QIODevice::ReadWrite | QIODevice::Text))
@@ -443,7 +443,7 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
         bool upload = data.toBool();
         if(upload)
         {
-            QFile confFile("/home/user/MyDocs/qtirreco/themes/" + themeToUploadDir + "/theme.conf");
+            QFile confFile(themesPath + themeToUploadDir + "/theme.conf");
             if (!confFile.open(QIODevice::ReadWrite | QIODevice::Text))
             {
                 QMessageBox::warning(this,"Error","Couldn't edit theme config!",
@@ -457,7 +457,7 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
 
             fileData.replace("source=own","source=database",Qt::CaseInsensitive);
 
-            QFile newConfFile("/home/user/MyDocs/qtirreco/themes/" + themeToUploadDir + "/theme.conf");
+            QFile newConfFile(themesPath + themeToUploadDir + "/theme.conf");
             if (!newConfFile.open(QIODevice::ReadWrite | QIODevice::Text))
             {
                 QMessageBox::warning(this,"Error","Couldn't edit theme config!",
@@ -514,7 +514,7 @@ void ThemeManager::getBgImage()
     params.append(pressedName);
     bgToFile = client->call("getImageData",params);
 }
-void ThemeManager::getThemeButtonsByIds() // HOXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX BUTTONCONFFIN DOWNLOADESSA PADDINGII YMS EI OTETA VIELÄ HUOMIOON !!!!!!!
+void ThemeManager::getThemeButtonsByIds() // Padding in button config not used ?
 {
      if(themeButtonIndex < dbButtonIdsList.count())
         {
@@ -575,11 +575,11 @@ void ThemeManager::on_downloadPushButton_clicked()
         QString version;
         versionFound = false;
         QString themeName = m_ui->listWidget->currentItem()->text().toLower();
-        QDir dir("/home/user/MyDocs/qtirreco/themes/" + themeName);
+        QDir dir(themesPath + themeName);
         if(dir.exists())
         {
             // Read version from conf file
-            QFile file("/home/user/MyDocs/qtirreco/themes/"+themeName+"/theme.conf");
+            QFile file(themesPath+themeName+"/theme.conf");
             if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
             {
                 QMessageBox::warning(this,"Error with theme config","Couldn't load " + themeName + " theme config file!" +
@@ -740,7 +740,7 @@ void ThemeManager::fault(int i,int j,QString string)
 void ThemeManager::loadThemes()
 {
 
-    QDir *themeDirs = new QDir("/home/user/MyDocs/qtirreco/themes/");
+    QDir *themeDirs = new QDir(themesPath);
 
     strList = themeDirs->entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
     themeDirList = strList;
@@ -750,7 +750,7 @@ void ThemeManager::loadThemes()
     {
         QListWidgetItem *item = new QListWidgetItem();
 
-        QString themeConf = "/home/user/MyDocs/qtirreco/themes/" + strList.at(i) + "/theme.conf";
+        QString themeConf = themesPath + strList.at(i) + "/theme.conf";
         QFile file(themeConf);
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
                  QMessageBox::warning(this,"Error with theme config","Couldn't load " + strList.at(i) + " theme config file!" +
@@ -814,7 +814,7 @@ void ThemeManager::readThemeConf(QString line)
                 button.replace(QChar(' '),QString("_"),Qt::CaseInsensitive); // If line contains space replace with _
                 uploadPreviewName = button;
                 QPalette palette;
-                palette.setBrush(QPalette::Window, QPixmap("/home/user/MyDocs/qtirreco/themes/"+tName+"/buttons/"+button.toLower()+"/unpressed.png").scaled(128,128,Qt::IgnoreAspectRatio,Qt::FastTransformation));
+                palette.setBrush(QPalette::Window, QPixmap(themesPath+tName+"/buttons/"+button.toLower()+"/unpressed.png").scaled(128,128,Qt::IgnoreAspectRatio,Qt::FastTransformation));
                 m_ui->pictureLabel->setPalette(palette);
                 m_ui->pictureLabel->setAutoFillBackground(true);
             }
@@ -870,7 +870,7 @@ void ThemeManager::on_deletePushButton_clicked()
     QString themeToDeleteName = m_ui->listWidget->currentItem()->text();
     bool themeUsedInRemote = false;
     QStringList themesUsedInRemotes;
-    QDir dir("/home/user/MyDocs/qtirreco/Remotes/");
+    QDir dir(remotesPath);
     QStringList remoteFiles = dir.entryList(QDir::Files);
 
     for(int i=0;i<remoteFiles.count();i++) {
@@ -881,7 +881,7 @@ void ThemeManager::on_deletePushButton_clicked()
 
     // Fill usedThemes
     for(int i=0;i<remoteFiles.count();i++) {
-        QFile file("/home/user/MyDocs/qtirreco/Remotes/" + remoteFiles.at(i));
+        QFile file(remotesPath + remoteFiles.at(i));
         file.open(QIODevice::ReadOnly | QIODevice::Text);
            QTextStream in(&file);
            while (!in.atEnd()) {
@@ -890,7 +890,6 @@ void ThemeManager::on_deletePushButton_clicked()
            }
         if(usedThemesByRemote.contains(themeToDelete,Qt::CaseInsensitive))
             remoteNamesUsingThemeToBeDeleted.append(remoteFiles.at(i));
-        //usedThemes.clear();
         usedThemesByRemote.clear();
         file.close();
     }
@@ -957,35 +956,35 @@ void ThemeManager::deleteTheme(QString delThemeName)
 {
     QDir dir;
     QString homePath = dir.currentPath();
-    dir.setPath("/home/user/MyDocs/qtirreco/themes/" + delThemeName + "/buttons/");
+    dir.setPath(themesPath + delThemeName + "/buttons/");
     QStringList buttonDirs = dir.entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
     for(int i=0;i<buttonDirs.count();i++)
     {
-        dir.setPath("/home/user/MyDocs/qtirreco/themes/" + delThemeName + "/buttons/" + buttonDirs.at(i));
+        dir.setPath(themesPath + delThemeName + "/buttons/" + buttonDirs.at(i));
         QStringList buttonFiles = dir.entryList(QDir::Files);
         for(int j=0;j<buttonFiles.count();j++)
         {
-            QFile file("/home/user/MyDocs/qtirreco/themes/" + delThemeName + "/buttons/" + buttonDirs.at(i) + "/" + buttonFiles.at(j));
+            QFile file(themesPath + delThemeName + "/buttons/" + buttonDirs.at(i) + "/" + buttonFiles.at(j));
             file.remove();
         }
     }
-    dir.setPath("/home/user/MyDocs/qtirreco/themes/" + delThemeName + "/bg/");
+    dir.setPath(themesPath + delThemeName + "/bg/");
     QStringList bgDirs = dir.entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
     for(int i=0;i<bgDirs.count();i++)
     {
-        dir.setPath("/home/user/MyDocs/qtirreco/themes/" + delThemeName + "/bg/" + bgDirs.at(i));
+        dir.setPath(themesPath + delThemeName + "/bg/" + bgDirs.at(i));
         QStringList bgFiles = dir.entryList(QDir::Files);
         for(int j=0;j<bgFiles.count();j++)
         {
-            QFile file("/home/user/MyDocs/qtirreco/themes/" + delThemeName + "/bg/" + bgDirs.at(i) + "/" + bgFiles.at(j));
+            QFile file(themesPath + delThemeName + "/bg/" + bgDirs.at(i) + "/" + bgFiles.at(j));
             file.remove();
         }
     }
-    dir.setPath("/home/user/MyDocs/qtirreco/themes/" + delThemeName + "/");
+    dir.setPath(themesPath + delThemeName + "/");
     QStringList extraFiles = dir.entryList(QDir::Files);
     for(int i=0;i<extraFiles.count();i++)
     {
-        QFile file("/home/user/MyDocs/qtirreco/themes/" + delThemeName + "/" + extraFiles.at(i));
+        QFile file(themesPath + delThemeName + "/" + extraFiles.at(i));
         file.remove();
     }
     dir.setPath(homePath);
@@ -996,41 +995,41 @@ void ThemeManager::deleteTheme()
 {
     QDir dir;
     QString homePath = dir.currentPath();
-    dir.setPath("/home/user/MyDocs/qtirreco/themes/" + themeToDelete + "/buttons/");
+    dir.setPath(themesPath + themeToDelete + "/buttons/");
     QStringList buttonDirs = dir.entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
     for(int i=0;i<buttonDirs.count();i++)
     {
-        dir.setPath("/home/user/MyDocs/qtirreco/themes/" + themeToDelete + "/buttons/" + buttonDirs.at(i));
+        dir.setPath(themesPath + themeToDelete + "/buttons/" + buttonDirs.at(i));
         QStringList buttonFiles = dir.entryList(QDir::Files);
         for(int j=0;j<buttonFiles.count();j++)
         {
-            QFile file("/home/user/MyDocs/qtirreco/themes/" + themeToDelete + "/buttons/" + buttonDirs.at(i) + "/" + buttonFiles.at(j));
+            QFile file(themesPath + themeToDelete + "/buttons/" + buttonDirs.at(i) + "/" + buttonFiles.at(j));
             file.remove();
         }
     }
-    dir.setPath("/home/user/MyDocs/qtirreco/themes/" + themeToDelete + "/bg/");
+    dir.setPath(themesPath + themeToDelete + "/bg/");
     QStringList bgDirs = dir.entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
     for(int i=0;i<bgDirs.count();i++)
     {
-        dir.setPath("/home/user/MyDocs/qtirreco/themes/" + themeToDelete + "/bg/" + bgDirs.at(i));
+        dir.setPath(themesPath + themeToDelete + "/bg/" + bgDirs.at(i));
         QStringList bgFiles = dir.entryList(QDir::Files);
         for(int j=0;j<bgFiles.count();j++)
         {
-            QFile file("/home/user/MyDocs/qtirreco/themes/" + themeToDelete + "/bg/" + bgDirs.at(i) + "/" + bgFiles.at(j));
+            QFile file(themesPath + themeToDelete + "/bg/" + bgDirs.at(i) + "/" + bgFiles.at(j));
             file.remove();
         }
     }
-    dir.setPath("/home/user/MyDocs/qtirreco/themes/" + themeToDelete + "/");
+    dir.setPath(themesPath + themeToDelete + "/");
     QStringList extraFiles = dir.entryList(QDir::Files);
     for(int i=0;i<extraFiles.count();i++)
     {
-        QFile file("/home/user/MyDocs/qtirreco/themes/" + themeToDelete + "/" + extraFiles.at(i));
+        QFile file(themesPath + themeToDelete + "/" + extraFiles.at(i));
         file.remove();
     }
     dir.setPath(homePath);
     QString delCommand("rm -rf /home/user/MyDocs/qtirreco/themes/" + themeToDelete);
     system(delCommand.toAscii().data());
-    QDir themeDir("/home/user/MyDocs/qtirreco/themes/" + themeToDelete);
+    QDir themeDir(themesPath + themeToDelete);
     if(!themeDir.exists())
     {
         QMessageBox::information(this,"Theme manager","Theme deleted succesfully.",
@@ -1059,42 +1058,42 @@ void ThemeManager::replaceTheme()
 {
     QDir dir;
     QString homePath = dir.currentPath();
-    dir.setPath("/home/user/MyDocs/qtirreco/themes/" + themeToDelete + "/buttons/");
+    dir.setPath(themesPath + themeToDelete + "/buttons/");
     QStringList buttonDirs = dir.entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
     for(int i=0;i<buttonDirs.count();i++)
     {
-        dir.setPath("/home/user/MyDocs/qtirreco/themes/" + themeToDelete + "/buttons/" + buttonDirs.at(i));
+        dir.setPath(themesPath + themeToDelete + "/buttons/" + buttonDirs.at(i));
         QStringList buttonFiles = dir.entryList(QDir::Files);
         for(int j=0;j<buttonFiles.count();j++)
         {
-            QFile file("/home/user/MyDocs/qtirreco/themes/" + themeToDelete + "/buttons/" + buttonDirs.at(i) + "/" + buttonFiles.at(j));
+            QFile file(themesPath + themeToDelete + "/buttons/" + buttonDirs.at(i) + "/" + buttonFiles.at(j));
             file.remove();
         }
     }
-    dir.setPath("/home/user/MyDocs/qtirreco/themes/" + themeToDelete + "/bg/");
+    dir.setPath(themesPath + themeToDelete + "/bg/");
     QStringList bgDirs = dir.entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
     for(int i=0;i<bgDirs.count();i++)
     {
-        dir.setPath("/home/user/MyDocs/qtirreco/themes/" + themeToDelete + "/bg/" + bgDirs.at(i));
+        dir.setPath(themesPath + themeToDelete + "/bg/" + bgDirs.at(i));
         QStringList bgFiles = dir.entryList(QDir::Files);
         for(int j=0;j<bgFiles.count();j++)
         {
-            QFile file("/home/user/MyDocs/qtirreco/themes/" + themeToDelete + "/bg/" + bgDirs.at(i) + "/" + bgFiles.at(j));
+            QFile file(themesPath + themeToDelete + "/bg/" + bgDirs.at(i) + "/" + bgFiles.at(j));
             file.remove();
         }
     }
-    dir.setPath("/home/user/MyDocs/qtirreco/themes/" + themeToDelete + "/");
+    dir.setPath(themesPath + themeToDelete + "/");
     QStringList extraFiles = dir.entryList(QDir::Files);
     for(int i=0;i<extraFiles.count();i++)
     {
-        QFile file("/home/user/MyDocs/qtirreco/themes/" + themeToDelete + "/" + extraFiles.at(i));
+        QFile file(themesPath + themeToDelete + "/" + extraFiles.at(i));
         file.remove();
     }
     dir.setPath(homePath);
     QString delCommand("rm -rf /home/user/MyDocs/qtirreco/themes/" + themeToDelete);
     system(delCommand.toAscii().data());
 
-    QDir themeDir("/home/user/MyDocs/qtirreco/themes/" + themeToDelete);
+    QDir themeDir(themesPath + themeToDelete);
     if(!themeDir.exists())
     {
         progress = new QProgressBar(this);
@@ -1158,15 +1157,15 @@ void ThemeManager::uploadThemeButton()
     QDir dir;
     QString homePath = dir.currentPath();
     QDir d;
-    d.setPath("/home/user/MyDocs/qtirreco/themes/" + themeToUploadDir + "/bg/");
+    d.setPath(themesPath + themeToUploadDir + "/bg/");
     QStringList bgs = d.entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
-    dir.setPath("/home/user/MyDocs/qtirreco/themes/" + themeToUploadDir + "/buttons/");
+    dir.setPath(themesPath + themeToUploadDir + "/buttons/");
     QStringList buttonDirs = dir.entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
     uploadItemsCount = buttonDirs.count() + bgs.count();;
     if(uploadButtonIndex < buttonDirs.count())
     {
         // Read button conf
-        QFile file("/home/user/MyDocs/qtirreco/themes/" + themeToUploadDir + "/buttons/" + buttonDirs.at(uploadButtonIndex)+"/button.conf");
+        QFile file(themesPath + themeToUploadDir + "/buttons/" + buttonDirs.at(uploadButtonIndex)+"/button.conf");
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
                 {
                     QMessageBox::warning(this,"Error","Couldn't load button config!",
@@ -1181,7 +1180,7 @@ void ThemeManager::uploadThemeButton()
                 }
         file.close();
         // Button image base64 strings and hashs
-        QImage imageUp("/home/user/MyDocs/qtirreco/themes/" + themeToUploadDir + "/buttons/" + buttonDirs.at(uploadButtonIndex)+"/unpressed.png");
+        QImage imageUp(themesPath + themeToUploadDir + "/buttons/" + buttonDirs.at(uploadButtonIndex)+"/unpressed.png");
         QBuffer buffer;
         buffer.open(QIODevice::WriteOnly);
         imageUp.save(&buffer,"PNG");
@@ -1192,7 +1191,7 @@ void ThemeManager::uploadThemeButton()
         uploadImageUpBase64 = QString(arr.toBase64());
         buffer.close();
 
-        QImage imageDown("/home/user/MyDocs/qtirreco/themes/" + themeToUploadDir + "/buttons/" + buttonDirs.at(uploadButtonIndex)+"/pressed.png");
+        QImage imageDown(themesPath + themeToUploadDir + "/buttons/" + buttonDirs.at(uploadButtonIndex)+"/pressed.png");
         QBuffer buffer2;
         buffer2.open(QIODevice::WriteOnly);
         imageDown.save(&buffer2,"PNG");
@@ -1252,12 +1251,12 @@ void ThemeManager::uploadThemeBg()
 
     QDir dir;
     QString homePath = dir.currentPath();
-    dir.setPath("/home/user/MyDocs/qtirreco/themes/" + themeToUploadDir + "/bg/");
+    dir.setPath(themesPath + themeToUploadDir + "/bg/");
     QStringList bgDirs = dir.entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
     if(uploadBgIndex < bgDirs.count())
     {
         // Read background conf
-        QFile file("/home/user/MyDocs/qtirreco/themes/" + themeToUploadDir + "/bg/" + bgDirs.at(uploadBgIndex)+"/bg.conf");
+        QFile file(themesPath + themeToUploadDir + "/bg/" + bgDirs.at(uploadBgIndex)+"/bg.conf");
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
                 {
                     QMessageBox::warning(this,"Error","Couldn't load background config!",
@@ -1272,7 +1271,7 @@ void ThemeManager::uploadThemeBg()
                 }
         file.close();
         // bg image base64 string and hash
-        QImage bg("/home/user/MyDocs/qtirreco/themes/" + themeToUploadDir + "/bg/" + bgDirs.at(uploadBgIndex)+"/image.png");
+        QImage bg(themesPath + themeToUploadDir + "/bg/" + bgDirs.at(uploadBgIndex)+"/image.png");
         QBuffer buffer;
         buffer.open(QIODevice::WriteOnly);
         bg.save(&buffer,"PNG");
