@@ -60,7 +60,7 @@ void UploadDBDlg::uploadRemote(QString username,QString pwd)
     /////////////////////////////////
     userName = username;
     password = pwd;
-    QFile file("/home/user/MyDocs/qtirreco/Remotes/"+ fileName + ".conf");
+    QFile file(remotesPath + fileName + ".conf");
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
         QMessageBox::information(this,"Remote upload","Remote config is not readable.",
                              QMessageBox::NoButton,QMessageBox::NoButton);
